@@ -307,6 +307,24 @@ class TraceView(pg.PlotWidget):
         self.callback(mouseT, event.button())
 
 
+class TrackView(TraceView):
+
+    def update_trace(self):
+        self.clear()
+
+        # draw individ channels
+        cols = self.m.bodypart_colors[self.m.track_sel_names]
+        for ii in range(self.m.y_tracks.shape[1]):
+            item = pg.PlotCurveItem(self.m.x_tracks, self.m.y_tracks[:, ii], pen=pg.mkPen(color=cols[ii]))
+            self.addItem(item)
+        self.autoRange(padding=0)
+
+        # time of current frame in trace
+        pos_line = pg.InfiniteLine(self.m.x_tracks[int(self.m.span / self.m.fs_ratio / 2)], movable=False, angle=90,
+                                   pen=pg.mkPen(color='r', width=1))
+        self.addItem(pos_line)
+
+
 class SpecView(pg.ImageView):
 
     def __init__(self, model, callback, colormap=None):
@@ -318,7 +336,8 @@ class SpecView(pg.ImageView):
         self.view.setAspectLocked(False)
         self.view.getViewBox().invertY(False)
         self.view.setMouseEnabled(x=False, y=False)
-        # leave enought space so axes are aligned aligned
+
+        # leave enough space so axes are aligned aligned
         y_axis = self.getView().getAxis('left')
         y_axis.setWidth(50)
         y_axis.setLabel('Frequency', units='Hz')
@@ -358,7 +377,7 @@ class SpecView(pg.ImageView):
 
     def update_spec(self, x, y):
         # hash x to avoid re-calculation? only useful when annotating
-        t0 = time.time()
+        # t0 = time.time()
         # t1 = time.time()
         # logging.debug(f'  update spec - clear annotations: {t1-t0}')
 
@@ -366,18 +385,18 @@ class SpecView(pg.ImageView):
         S, f, t = self._calc_spec(tuple(y), self.m.spec_win)  # tuple-ify for caching
         self.S = S
         trange = (self.m.x[-1] - self.m.x[0])
-        t2 = time.time()
-        logging.debug(f'  update spec - calc spec: {t2-t0}')
+        # t2 = time.time()
+        # logging.debug(f'  update spec - calc spec: {t2-t0}')
 
         self.setImage(S.T, autoRange=False, scale=[trange / len(t), (f[-1] - f[0]) / len(f)], pos=[self.m.x[0], f[0]])
         self.view.setRange(xRange=self.m.x[[0, -1]], yRange=(f[0], f[-1]), padding=0)
 
         self.pos_line.setValue(self.m.x[int(self.m.span / 2)])
 
-        t3 = time.time()
-        logging.debug(f'  update spec - draw: {t3-t2}')
-        t4 = time.time()
-        logging.debug(f'update spec - TOTAL: {t4-t0}')
+        # t3 = time.time()
+        # logging.debug(f'  update spec - draw: {t3-t2}')
+        # t4 = time.time()
+        # logging.debug(f'update spec - TOTAL: {t4-t0}')
 
     @lru_cache(maxsize=2, typed=False)
     def _calc_spec(self, y, spec_win):
@@ -478,9 +497,13 @@ class MovieView(utils.FastImageWidget):
                 self.fly_pens.append(pg.mkBrush(*self.m.fly_colors[dot_fly], alpha))
 
         # build skeletons
-        skeleton = np.array([[0, 1], [1, 8], [8, 11],  # body axis
-                             [8, 2], [8, 3], [8, 4], [8, 5], [8, 6], [8, 7],  # legs
-                             [8, 9], [8, 10]])  # wings
+        if 'pose_positions' in self._m.ds:
+            skeleton = self._m.ds.pose_positions.attrs['skeleton']
+        else:
+            skeleton = np.zeros((0, 2), dtype=np.uint)
+        # skeleton = np.array([[0, 1], [1, 8], [8, 11],  # body axis
+        #                      [8, 2], [8, 3], [8, 4], [8, 5], [8, 6], [8, 7],  # legs
+        #                      [8, 9], [8, 10]])  # wings
         self.skeletons = np.zeros((0, 2), dtype=np.uint)
         for dot_fly in range(self.m.nb_flies):
             self.skeletons = np.append(self.skeletons, self.m.nb_bodyparts * dot_fly + skeleton, axis=0)
@@ -492,6 +515,13 @@ class MovieView(utils.FastImageWidget):
 
     def update_frame(self, ):
         frame = self.m.vr[self.m.framenumber]
+
+        if self.m.frame_fliplr:
+            frame = np.ascontiguousarray(frame[:, ::-1])
+
+        if self.m.frame_flipud:
+            frame = np.ascontiguousarray(frame[::-1, :])
+
         if frame is not None:  # frame is None when at end of video
             # # FIXME the annotations potentially waste time annotating outside of the cropped frame
             if 'pose_positions_allo' in self.m.ds:
@@ -517,19 +547,16 @@ class MovieView(utils.FastImageWidget):
 
             self.setImage(frame, auto_scale=True)
             self.viewBox.setRange(xRange=y_range, yRange=x_range)
-            # if self.m.show_framenumber:
-            #     self.image_view_framenumber_text.setPlainText(f'frame {self.m.framenumber}')
-            # else:
-            #     self.image_view_framenumber_text.setPlainText('')
 
     def annotate_dot(self, frame):
         # mark each fly with uniquely colored dots
         if 'pose_positions_allo' in self.m.ds:
-            pos = np.array(self.m.ds.pose_positions_allo.data[self.m.index_other, :, self.m.thorax_index])
-            cols = self.m.bodypart_colors[[2, 6]]
+            pos = np.array(self.m.ds.pose_positions_allo.data[self.m.index_other, :, self.m.pose_center_index])
+            cols = self.m.fly_colors
         elif 'body_positions' in self.m.ds:
-            pos = np.array(self.m.ds.body_positions.data[self.m.index_other, :, 1])
-            cols = self.m.bodypart_colors[[0]]
+            pos = np.array(self.m.ds.body_positions.data[self.m.index_other, :, self.m.track_center_index])
+            cols = self.m.fly_colors
+
         self.fly_positions.setData(pos=pos[:,::-1],
                                    symbolBrush=self.brushes, pen=None, size=10,
                                    acceptDrags=not self.m.move_poses,
@@ -538,9 +565,9 @@ class MovieView(utils.FastImageWidget):
         # mark *focal* and *other* fly with circle
         for this_fly, color in zip((self.m.focal_fly, self.m.other_fly), cols):
             if 'pose_positions_allo' in self.m.ds:
-                fly_pos = self.m.ds.pose_positions_allo.data[self.m.index_other, this_fly, self.m.thorax_index]
+                fly_pos = self.m.ds.pose_positions_allo.data[self.m.index_other, this_fly, self.m.pose_center_index]
             elif 'body_positions' in self.m.ds:
-                fly_pos = self.m.ds.body_positions.data[self.m.index_other, this_fly, 1]
+                fly_pos = self.m.ds.body_positions.data[self.m.index_other, this_fly, self.m.track_center_index]
 
             fly_pos = np.array(fly_pos).astype(np.uintp)  # in case this is a dask.array
             # only plot circle if fly is within the frame (also prevents overflow errors
@@ -561,9 +588,9 @@ class MovieView(utils.FastImageWidget):
 
     def crop_frame(self, frame):
         if 'pose_positions_allo' in self.m.ds:
-            fly_pos = self.m.ds.pose_positions_allo.data[self.m.index_other, self.m.focal_fly, self.m.thorax_index]
+            fly_pos = self.m.ds.pose_positions_allo.data[self.m.index_other, self.m.focal_fly, self.m.pose_center_index]
         elif 'body_positions' in self.m.ds:
-            fly_pos = self.m.ds.body_positions.data[self.m.index_other, self.m.focal_fly, 1]
+            fly_pos = self.m.ds.body_positions.data[self.m.index_other, self.m.focal_fly, self.m.track_center_index]
         fly_pos = np.array(fly_pos).astype(np.uintp)  # in case this is a dask.array
         # makes sure crop does not exceed frame bounds
         fly_pos[0] = np.clip(fly_pos[0], self.m.box_size, self.m.vr.frame_width - 1 - self.m.box_size)
